
<template>
  <view-grid
    ref="grid"
    :columns="columns"
    :detail="detail"
    :editFormFields="editFormFields"
    :editFormOptions="editFormOptions"
    :searchFormFields="searchFormFields"
    :searchFormOptions="searchFormOptions"
    :table="table"
    :extend="extend"
  >
  </view-grid>
</template>
      <script>
import extend from "@/extension/basic/palletCodeInfo.js";
import { ref, defineComponent } from "vue";
export default defineComponent({
  setup() {
    const table = ref({
      key: "id",
      footer: "Foots",
      cnName: "托盘信息",
      name: "palletCodeInfo",
      url: "/PalletCodeInfo/",
      sortName: "id",
    });
    const editFormFields = ref({});
    const editFormOptions = ref([
      [
        {
          title: "仓库",
          field: "warehouseId",
          type: "select",
          dataKey: "warehouses",
          data: [],
          required: true,
        },
        {
          title: "数量",
          field: "count",
          type: "int",
          required: true,
        },
      ],
    ]);
    const searchFormFields = ref({
      palletCode: "",
    });
    const searchFormOptions = ref([
      [{ title: "托盘编号", field: "palletCode", type: "like" }],
    ]);
    const columns = ref([
      {
        field: "id",
        title: "Id",
        type: "int",
        width: 90,
        hidden: true,
        readonly: true,
        require: true,
        align: "left",
      },
      {
        field: "warehouseId",
        title: "仓库主键",
        type: "string",
        width: 90,
        align: "left",
        bind: { key: "warehouse", data: [] },
      },
      {
        field: "palletType",
        title: "托盘类型",
        type: "string",
        width: 150,
        align: "left",
      },
      {
        field: "palletCode",
        title: "托盘编号",
        type: "decimal",
        width: 90,
        align: "left",
      },
      {
        field: "status",
        title: "打印状态",
        type: "string",
        width: 90,
        align: "left",
        bind: { key: "enableEnum", data: [] },
      },
      {
        field: "size",
        title: "尺寸",
        type: "int",
        width: 120,
        align: "left",
      },
      {
        field: "creater",
        title: "创建人",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "createDate",
        title: "创建时间",
        type: "datetime",
        width: 160,
        align: "left",
        sort: true,
      },
      {
        field: "modifier",
        title: "修改人",
        type: "string",
        width: 100,
        align: "left",
      },
      {
        field: "modifyDate",
        title: "修改时间",
        type: "datetime",
        width: 160,
        align: "left",
        sort: true,
      },
      {
        field: "remark",
        title: "备注",
        type: "string",
        width: 100,
        align: "left",
      },
    ]);
    const detail = ref({
      cnName: "#detailCnName",
      table: "",
      columns: [],
      sortName: "",
    });
    return {
      table,
      extend,
      editFormFields,
      editFormOptions,
      searchFormFields,
      searchFormOptions,
      columns,
      detail,
    };
  },
});
</script>
      